
:autogenerated:
..
    This file is autogenerated by `generate_custom_files` in conf.py,
    and ought to be generated via building the documentation through Sphinx, e.g.
    with `sphinx-build ./web ./build` from the root directory.

nltk.test.unit package
======================

.. automodule:: nltk.test.unit
    :members:
    :undoc-members:
    :show-inheritance:


***********
Subpackages
***********

    .. toctree::
       :maxdepth: 1

       nltk.test.unit.lm
       nltk.test.unit.translate


**********
Submodules
**********

    .. toctree::
       :maxdepth: 1

       nltk.test.unit.test_aline
       nltk.test.unit.test_bllip
       nltk.test.unit.test_brill
       nltk.test.unit.test_cfd_mutation
       nltk.test.unit.test_cfg2chomsky
       nltk.test.unit.test_chunk
       nltk.test.unit.test_classify
       nltk.test.unit.test_collocations
       nltk.test.unit.test_concordance
       nltk.test.unit.test_corenlp
       nltk.test.unit.test_corpora
       nltk.test.unit.test_corpus_views
       nltk.test.unit.test_data
       nltk.test.unit.test_disagreement
       nltk.test.unit.test_distance
       nltk.test.unit.test_downloader
       nltk.test.unit.test_freqdist
       nltk.test.unit.test_hmm
       nltk.test.unit.test_json2csv_corpus
       nltk.test.unit.test_json_serialization
       nltk.test.unit.test_metrics
       nltk.test.unit.test_naivebayes
       nltk.test.unit.test_nombank
       nltk.test.unit.test_pl196x
       nltk.test.unit.test_pos_tag
       nltk.test.unit.test_ribes
       nltk.test.unit.test_rte_classify
       nltk.test.unit.test_seekable_unicode_stream_reader
       nltk.test.unit.test_senna
       nltk.test.unit.test_stem
       nltk.test.unit.test_tag
       nltk.test.unit.test_tgrep
       nltk.test.unit.test_tokenize
       nltk.test.unit.test_twitter_auth
       nltk.test.unit.test_util
       nltk.test.unit.test_wordnet